This is an SDK to make integration with the RedBrick AI platform as easy as possible. This includes uploading and downloading data
as well as making your datasets easily available for training. Use this SDK to access your data and labels anywhere you run your code, whether that is on the cloud or locally with a Jupyter Notebook.

Please feel free to submit issues on github or at [support@redbrickai.com](mailto:support@redbrickai.com) if you run into any problems or have suggestions.

Visit [docs.redbrickai.com/python-sdk/sdk-overview](https://docs.redbrickai.com/python-sdk/sdk-overview) for tutorials on how to use this library.


